@@ -1,8 +1,8 @@
 //----------------------------------------------------------------------
+// Copyright 2007-2023 Cadence Design Systems, Inc.
 // Copyright 2009-2011 Mentor Graphics Corporation
+// Copyright 2013-2024 NVIDIA Corporation
 // Copyright 2010-2011 Synopsys, Inc.
-// Copyright 2007-2018 Cadence Design Systems, Inc.
-// Copyright 2013 NVIDIA Corporation
 //   All Rights Reserved Worldwide
 //
 //   Licensed under the Apache License, Version 2.0 (the
@@ -20,6 +20,16 @@
 //   permissions and limitations under the License.
 //----------------------------------------------------------------------
 
+//----------------------------------------------------------------------
+// Git details (see DEVELOPMENT.md):
+//
+// $File:     src/dpi/uvm_hdl_xcelium.c $
+// $Rev:      2024-02-08 13:43:04 -0800 $
+// $Hash:     29e1e3f8ee4d4aa2035dba1aba401ce1c19aa340 $
+//
+//----------------------------------------------------------------------
+
+
 // use -DINCA_EXTENDED_PARTSEL_SUPPORT to use extended support for vpi_handle_by_name
 
 #include "vhpi_user.h"
@@ -273,7 +283,7 @@ static int uvm_hdl_set_vlog(char *path, p_vpi_vecval value, PLI_INT32 flag)
 
 static vhpiEnumT vhpiEnumTLookup[4] = {vhpi0,vhpi1,vhpiZ,vhpiX}; // idx={b[0],a[0]}
 static vhpiEnumT vhpi2val(int aval,int bval) {
-  int idx=(((bval<<1) || (aval&1)) && 3);
+  int idx=(((bval<<1) | (aval&1)) & 3);
   return vhpiEnumTLookup[idx];
 }
 
